==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/shells/generic/iggdialogauto.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iconfigure.h"
#if ISHELL_INCLUDED(ISHELL_GG)


#include "iggdialogauto.h"


#include "iggmainwindow.h"

#include "ibgdialogsubject.h"


bool iggDialogAuto::mBlockShowing = false;


iggDialogAuto::iggDialogAuto(iggMainWindow *mw, const iString &title, int cols) : iggDialog(mw,0U,0,title,0,cols), mTitle(title)
{
	if(mMainWindow != 0) mMainWindow->RegisterAutoDialog(this);
	this->ResizeContents(0,0);
}


iggDialogAuto::~iggDialogAuto()
{
	if(mMainWindow != 0) mMainWindow->UnRegisterAutoDialog(this);
}


void iggDialogAuto::Show(bool s)
{
	if(!s || !mBlockShowing)
	{
		this->ForceShow(s);
	}
}


void iggDialogAuto::ForceShow(bool s)
{
	this->iggDialog::Show(s);
	if((mMode & iParameter::DialogFlag::Modal) == 0) this->GetMainWindow()->PlaceAutoDialogs();
}

#endif

==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/shells/generic/iggdialogauto.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iconfigure.h"
#if ISHELL_INCLUDED(ISHELL_GG)


#include "iggdialogauto.h"


#include "iggmainwindow.h"

#include "ibgdialogsubject.h"


bool iggDialogAuto::mBlockShowing = false;


iggDialogAuto::iggDialogAuto(iggMainWindow *mw, const iString &title, int cols) : iggDialog(mw,0U,0,title,0,cols), mTitle(title)
{
	if(mMainWindow != 0) mMainWindow->RegisterAutoDialog(this);
	this->ResizeContents(0,0);
}


iggDialogAuto::~iggDialogAuto()
{
	if(mMainWindow != 0) mMainWindow->UnRegisterAutoDialog(this);
}


void iggDialogAuto::ShowBody(bool s)
{
	if(!s || !mBlockShowing)
	{
		this->ForceShow(s);
	}
}


void iggDialogAuto::ForceShow(bool s)
{
	if(!mCompleteConstructionCalled) this->CompleteConstruction();
	this->iggDialog::ShowBody(s);
	if((mMode & iParameter::DialogFlag::Modal) == 0) this->GetMainWindow()->PlaceAutoDialogs();
}

#endif
